==> webkit2gtk_2.23.1.orig.tar.xz: webkitgtk-2.23.1/Source/WebKit/UIProcess/WebAuthentication/Mock/MockWebAuthenticationConfiguration.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_AUTHN)

#include <wtf/text/WTFString.h>

namespace WebKit {

struct MockWebAuthenticationConfiguration {
    struct Local {
        bool acceptAuthentication { false };
        bool acceptAttestation { false };
        String privateKeyBase64;
        String userCertificateBase64;
        String intermediateCACertificateBase64;
    };

    struct Hid {
        enum class Stage : bool {
            Info,
            Request
        };

        enum class SubStage : bool {
            Init,
            Msg
        };

        enum class Error : uint8_t {
            Success,
            DataNotSent,
            EmptyReport,
            WrongChannelId,
            MaliciousPayload,
            UnsupportedOptions,
            WrongNonce
        };

        String payloadBase64;
        Stage stage { Stage::Info };
        SubStage subStage { SubStage::Init };
        Error error { Error::Success };
        bool keepAlive { false };
        bool fastDataArrival { false };
        bool continueAfterErrorData { false };
    };

    bool silentFailure { false };
    std::optional<Local> local;
    std::optional<Hid> hid;
};

} // namespace WebKit

#endif // ENABLE(WEB_AUTHN)

==> webkit2gtk_2.23.2.orig.tar.xz: webkitgtk-2.23.2/Source/WebKit/UIProcess/WebAuthentication/Mock/MockWebAuthenticationConfiguration.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_AUTHN)

#include <wtf/text/WTFString.h>

namespace WebKit {

struct MockWebAuthenticationConfiguration {
    struct Local {
        bool acceptAuthentication { false };
        bool acceptAttestation { false };
        String privateKeyBase64;
        String userCertificateBase64;
        String intermediateCACertificateBase64;
    };

    struct Hid {
        enum class Stage : bool {
            Info,
            Request
        };

        enum class SubStage : bool {
            Init,
            Msg
        };

        enum class Error : uint8_t {
            Success,
            DataNotSent,
            EmptyReport,
            WrongChannelId,
            MaliciousPayload,
            UnsupportedOptions,
            WrongNonce
        };

        String payloadBase64;
        Stage stage { Stage::Info };
        SubStage subStage { SubStage::Init };
        Error error { Error::Success };
        bool keepAlive { false };
        bool fastDataArrival { false };
        bool continueAfterErrorData { false };
    };

    bool silentFailure { false };
    Optional<Local> local;
    Optional<Hid> hid;
};

} // namespace WebKit

#endif // ENABLE(WEB_AUTHN)
